@@ -16,7 +16,17 @@ class Flavour:
 
     @property
     def px(self) -> str:
-        return f"p{self.name.removesuffix('jets')}"
+        if self.name.endswith("jets"):
+            return f"p{self.name[: -len('jets')]}"
+        return f"p{self.name}"
+
+    @property
+    def eff_str(self) -> str:
+        return self.label.replace("jets", "jet") + " efficiency"
+
+    @property
+    def rej_str(self) -> str:
+        return self.label.replace("jets", "jet") + " rejection"
 
     def __str__(self) -> str:
         return self.name
@@ -38,8 +48,13 @@ class FlavourContainer:
     def __getattr__(self, name) -> Flavour:
         return self[name]
 
+    def __contains__(self, flavour: str | Flavour) -> bool:
+        if isinstance(flavour, Flavour):
+            flavour = flavour.name
+        return flavour in self.flavours
+
     def __repr__(self) -> str:
-        return f"FlavourContainer({', '.join(list(f.name for f in self))})"
+        return f"{self.__class__.__name__}({', '.join(list(f.name for f in self))})"
 
     @property
     def categories(self) -> list[str]:
@@ -47,3 +62,11 @@ class FlavourContainer:
 
     def by_category(self, category: str) -> FlavourContainer:
         return FlavourContainer({k: v for k, v in self.flavours.items() if v.category == category})
+
+    def from_cuts(self, cuts: list | Cuts) -> Flavour:
+        if isinstance(cuts, list):
+            cuts = Cuts.from_list(cuts)
+        for flavour in self:
+            if flavour.cuts == cuts:
+                return flavour
+        raise KeyError(f"Flavour with {cuts} not found")
